@@ -1,6 +1,6 @@
 package OpenInteract::Handler::Page;
 
-# $Id: Page.pm,v 1.39 2002/12/14 03:34:22 lachoy Exp $
+# $Id: Page.pm,v 1.40 2003/03/11 04:36:03 lachoy Exp $
 
 use strict;
 use Class::Date ();
@@ -11,7 +11,7 @@ use OpenInteract::Handler::GenericDispatcher qw( DEFAULT_SECURITY_KEY );
 use SPOPS::Secure qw( :level );
 
 @OpenInteract::Handler::Page::ISA     = qw( OpenInteract::CommonHandler  SPOPS::Secure );
-$OpenInteract::Handler::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.39 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.40 $ =~ /(\d+)\.(\d+)/);
 $OpenInteract::Handler::Page::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Page::default_method    = 'show';
 @OpenInteract::Handler::Page::forbidden_methods = ();
@@ -426,9 +426,12 @@ sub fetch_object {
     my ( $class, $id, @id_field ) = @_;
     my $R = OpenInteract::Request->instance;
     my $existing_location = $class->_read_field( $R->apache, 'old_location' );
+    my $fetch_id = ( $id =~ m|^/| ) ? $id : "/$id";
+    $R->DEBUG && $R->scrib( 1, "Pre-fetch: [Exist: $existing_location]",
+                            "[New: $fetch_id]" );
     return ( $existing_location )
              ? $class->SUPER::fetch_object( $existing_location, @id_field )
-             : $class->SUPER::fetch_object( $id, @id_field );
+             : $class->SUPER::fetch_object( $fetch_id, @id_field );
 }
 
 
@@ -483,11 +486,17 @@ sub _edit_customize {
     # changed the location, then we need to set the ID so the UPDATE
     # works properly.
 
-    elsif ( $page->{location} ne $old_data->{location} ) {
-        $opts{use_id} = $old_data->{location};
-        $R->DEBUG && $R->scrib( 1, "This should be an UPDATE where we change ",
-                                   "the primary key from [$old_data->{location}] ",
-                                   "to [$page->{location}]" );
+    else {
+        unless ( $page->{location} =~ m|^/| ) {
+            $page->{location} = "/$page->{location}";
+        }
+        if ( $old_data->{location} and
+            $page->{location} ne $old_data->{location} ) {
+            $opts{use_id} = $old_data->{location};
+            $R->DEBUG && $R->scrib( 1, "This should be an UPDATE where we change ",
+                                    "the primary key from [$old_data->{location}] ",
+                                    "to [$page->{location}]" );
+        }
     }
 
     # Ensure that the location is clean
