@@ -1,12 +1,12 @@
 package OpenInteract::Page;
 
-# $Id: Page.pm,v 1.21 2002/12/13 21:42:20 lachoy Exp $
+# $Id: Page.pm,v 1.23 2003/04/03 19:30:03 lachoy Exp $
 
 use strict;
 use Data::Dumper   qw( Dumper );
 use File::Basename qw();
 
-$OpenInteract::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.21 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.23 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_EXTENSION => '.html';
 
@@ -52,44 +52,72 @@ sub page_by_location {
     }
 
     # Onto the fun stuff.
-    # First check to see if this is directory request that corresponds
-    # to a page_directory object...
 
-    if ( $location =~ m|/$| or $location !~ /\.\w+$/ ) {
+    # Store our found page object
+    my ( $page );
+
+    # Store all potential locations
+    my @locations = ();
+
+    # First, if this isn't a directory request and we weren't given an
+    # extension, check just for that page. Otherwise we get into hinky
+    # business with directory indexing in the next step.
+
+    my $no_extension = $location !~ /\.\w+$/;
+    my $dir_request  = $location =~ m|/$|;
+    if ( ! $dir_request and $no_extension ) {
+        $page = eval { $R->page->fetch( $location ) };
+        if ( $@ ) {
+            $R->scrib( 0, "Caught error fetching [$location] as page: $@" );
+        }
+        elsif ( $page ) {
+            return $page;
+        }
+    }
+
+    # Check to see if this is directory request that corresponds to a
+    # page_directory object...
+
+    elsif ( $dir_request or $no_extension ) {
         $R->DEBUG && $R->scrib( 1, "Testing [$location] as a directory" );
-        my $dir = eval { $R->page_directory->fetch_by_directory( $location ) };
+        my $dir = eval {
+            $R->page_directory->fetch_by_directory( $location, 'yes' )
+        };
         if ( $@ ) {
             $R->scrib( 0, "Tried to fetch directory but got error: $@" );
         }
         if ( $dir ) {
-            $R->DEBUG && $R->scrib( 1, "Directory object found. Returning" );
+            $R->DEBUG && $R->scrib( 1, "Directory object found ",
+                                    "[$dir->{directory}]. Returning" );
             return $dir;
         }
         $R->DEBUG && $R->scrib( 1, "Directory object not found. Continuing..." );
     }
 
-    # It's not a page_directory request, so now figure out all the
-    # potential locations (stored in @locations)
+    # If we've made it to here, it's not a page_directory request and
+    # not a page requested without an extension; now figure out all
+    # the potential locations
 
-    my @locations = ();
-
-    push @locations, $location;
+    else {
+        push @locations, $location;
+    }
 
     my ( $extension ) = $location =~ /(\.\w+)$/;
     my $default_extension = $class->CONFIG->{default_extension} ||
                             DEFAULT_EXTENSION;
 
-    if ( $extension ) {
+    if ( $no_extension ) {
+        push @locations, join( '', $location, $default_extension );
+        $R->DEBUG && $R->scrib( 1, "Location has no extension; add check ",
+                                "for default extension [$locations[-1]]" ),
+    }
+    else {
         my ( $sans_extension );
         ( $sans_extension = $location ) =~ s/$extension$//;
         $R->DEBUG && $R->scrib( 1, "Also check location without the extension ",
                                    "using [$sans_extension]" );
         push @locations, $sans_extension;
     }
-    else {
-        $R->DEBUG && $R->scrib( 1, "Location has no extension; add default extension" ),
-        push @locations, join( '', $location, $default_extension );
-    }
 
     # Find things like
     #   (requested) /blah/bloo.shtml
@@ -102,7 +130,6 @@ sub page_by_location {
         push @locations, join( '', $root, $default_extension );
     }
 
-    my ( $page );
     my ( $error_type );
     foreach my $location ( @locations ) {
         # Skip empty locations and leading dotfiles (change?)
@@ -116,7 +143,7 @@ sub page_by_location {
             $error_type = SPOPS::Error->get->{type};
         }
         if ( $page ) {
-            $R->DEBUG && $R->scrib( 1, "Found matching location: [$page->{location}]" );
+            $R->DEBUG && $R->scrib( 1, "Found matching page: [$page->{location}]" );
             return $page;
         }
     }
@@ -151,6 +178,7 @@ sub clean_name {
                       $class->FUNNY_CHARACTERS;
     $name =~ s/^\.+//;
     $name =~ s/\.\./_/g;
+    $name =~ s/\.//g;
     $name =~ s/\s/_/g;
     $name =~ s/[$funny_chars]//g;
     return $name;
